//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-pdf-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;

namespace DsPdfWeb.Demos
{
    // This sample demonstrates all editing features of GcPdfViewer with support API
    // provided by the server running DsPdf. Note that unlike the viewer in most other
    // samples, in this sample the File Open button is available so you can load any PDF
    // into the viewer and see what its editing features can do with it.

    // This and other samples in this section demonstrate the features of GcPdfViewer
    // (a JavaScript PDF viewer control included with DsPdf), mainly the ability
    // to change PDF files (add or edit annotations and AcroForm fields, rotate pages etc.)
    // when the JS viewer on the client is supported by DsPdf running on the server.
    //
    // To enable the editing features of the viewer, its supportApi property must be set
    // to a URL on the server that implements all or some of the edit supporting APIs
    // that are known to/expected by the viewer. This DsPdf demo site provides those APIs,
    // which makes it possible to demonstrate the editing when you open the PDF viewer
    // in this sample. When you download this sample, in addition to the .NET Core
    // console app project that generates the sample PDF, an ASP.NET Core project is
    // also included in the download zip (located in the GcPdfViewerWeb sub-folder of the
    // downloaded zip), which also provides the necessary APIs. In particular, it includes
    // a project that implements the APIs and provides them via a special controller.
    // It is actually the same controller that is used by this DsPdf demo site, and which
    // can be used in any ASP.NET Core site to enable the viewer editing features.
    //
    // Look at the following files in the sample download zip for more info:
    // - GcPdfViewerWeb\SupportApiDemo: the sample ASP.NET Core web site.
    // - GcPdfViewerWeb\SupportApiDemo.sln: solution to build/run the sample web site.
    // - GcPdfViewerWeb\SupportApi: support API implementation (can be used in any site).
    // - GcPdfViewerWeb\SupportApi\Controllers\GcPdfViewerController.cs: support API controller.
    //
    // Please note that this and other samples in this section are only available in C# at this time.
    //
    public class ViewerEditAll
    {
        public void CreatePDF(Stream stream)
        {
            var doc = new GcPdfDocument();
            var page = doc.NewPage();

            Common.Util.AddNote("This sample provides access to all editing tools available in the DsPdfViewer when it is connected " +
                "to a server running DsPdf via viewer.supportApi property. " +
                "Use the File Open button (first in the top toolbar) to load any PDF into the viewer " +
                "(note that the maximum file size is limited, an error will occur if the limit is exceeded). " +
                "Use the first of the two buttons at the bottom of the left vertical toolbar to access the annotation editor " +
                "that allows adding, editing or removing annotations. " +
                "Use the second of the two buttons to access the AcroForm editor that allows adding, editing or removing form fields. " +
                "Note that clicking the active editor button toggles the visibility of the properties panel without exiting the edit mode.",
                page);

            // Save the PDF:
            doc.Save(stream);
        }

        // Used by SupportApiDemo to initialize GcPdfViewer.
        public static GcPdfViewerSupportApiDemo.Models.PdfViewerOptions PdfViewerOptions
        {
            get => new GcPdfViewerSupportApiDemo.Models.PdfViewerOptions(
                GcPdfViewerSupportApiDemo.Models.PdfViewerOptions.Options.AllPanels,
                viewerTools: new string[] { "open", "save", "$navigation", "$split", "text-selection", "pan", "$zoom", "$fullscreen", "download", "print",
                    "rotate", "view-mode", "hide-annotations", "doc-properties", "about" });
        }

        public const string JS_CODE = @"
var viewer;
function createPdfViewer(selector, baseOptions) {
    var options = baseOptions || {};
    if (!options.supportApi) {
        options.supportApi = {
            apiUrl: (window.__baseUrl || '') + 'support-api/gc-pdf-viewer',
            token: window.afToken || '',
            webSocketUrl: false, suppressInfoMessages: true, suppressErrorMessages: true
        };
    }
    viewer = new GcPdfViewer(selector, options);
    viewer.addDefaultPanels();
    viewer.addAnnotationEditorPanel();
    viewer.addFormEditorPanel();
    viewer.toolbarLayout.viewer = {
        default: [ 'open', 'save', '$navigation', '$split', 'text-selection', 'pan', '$zoom', '$fullscreen', 'download', 'print',
                    'rotate', 'view-mode', 'hide-annotations', 'doc-properties', 'about'],
        mobile: [ 'open', 'save', '$navigation', '$split', 'text-selection', 'pan', '$zoom', '$fullscreen', 'download', 'print',
                    'rotate', 'view-mode', 'hide-annotations', 'doc-properties', 'about'],
        fullscreen: ['$fullscreen', 'open', 'save', '$navigation', '$split', 'text-selection', 'pan', '$zoom', '$fullscreen', 'download', 'print',
                    'rotate', 'view-mode', 'hide-annotations', 'doc-properties', 'about']
    };
    viewer.applyToolbarLayout();
    return viewer;
}
";
    }
}
